## no critic (ProhibitMagicNumbers)
use strict;

use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::DHL::API::XML::DHLProductInfoHandler qw( ParseProductInfoXML );

use Test::More;
use Test::Exception;

sub Main {
    testParseProductInfoXML_With_NS5();
    testParseProductInfoXML_With_NS6();
    done_testing();
}

sub testParseProductInfoXML_With_NS5 {
    _testParseXML('Samples/DHLProductList/Product_List_NS5.xml', 31, 49);
}

sub testParseProductInfoXML_With_NS6 {
    _testParseXML('Samples/DHLProductList/Product_List_NS6.xml', 32, 107);
}

sub _testParseXML {
    my ($XMLFileName, $ExpectedDestinationParsed, $ExpectedProductsParsed) = @_;
    my $XML = _fileContentToString($XMLFileName);
    my $hProducts;
    lives_ok(sub { $hProducts = ParseProductInfoXML(1, $XML) } , 'no error with ns6');

    my $numberOfDestinationParsed = scalar keys(%{$hProducts->{destinations}});
    isnt($numberOfDestinationParsed, 0, "Some destinations have been read from $XMLFileName");
    is($numberOfDestinationParsed, $ExpectedDestinationParsed, "$ExpectedProductsParsed destinations are expected in $XMLFileName");

    my $numberOfProductsParsed = scalar keys(%{$hProducts->{products}});
    isnt($numberOfProductsParsed, 0, "Some products have been read from $XMLFileName");
    is($numberOfProductsParsed, $ExpectedProductsParsed, "$ExpectedProductsParsed products are expected in $XMLFileName");
}

sub _fileContentToString {
    my ($FileName) = @_;
    my $XMLString;
    if(defined($FileName)) {
        open(my $XMLFile, '<', $FileName) or die $!;
        do { local $/ = undef; $XMLString = <$XMLFile> };
        close($XMLFile) or die $!;
    }
    return $XMLString;
}

RunScript( Sub => \&Main );